==> openshift-model-machineconfig-5.12.0-sources.jar: io/fabric8/openshift/api/model/machineconfig/v1/MachineConfigBuilder.java <==
package io.fabric8.openshift.api.model.machineconfig.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class MachineConfigBuilder extends io.fabric8.openshift.api.model.machineconfig.v1.MachineConfigFluentImpl<io.fabric8.openshift.api.model.machineconfig.v1.MachineConfigBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.machineconfig.v1.MachineConfig,io.fabric8.openshift.api.model.machineconfig.v1.MachineConfigBuilder>{
  public MachineConfigBuilder() {
    this(false);
  }
  public MachineConfigBuilder(java.lang.Boolean validationEnabled) {
    this(new MachineConfig(), validationEnabled);
  }
  public MachineConfigBuilder(io.fabric8.openshift.api.model.machineconfig.v1.MachineConfigFluent<?> fluent) {
    this(fluent, false);
  }
  public MachineConfigBuilder(io.fabric8.openshift.api.model.machineconfig.v1.MachineConfigFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new MachineConfig(), validationEnabled);
  }
  public MachineConfigBuilder(io.fabric8.openshift.api.model.machineconfig.v1.MachineConfigFluent<?> fluent,io.fabric8.openshift.api.model.machineconfig.v1.MachineConfig instance) {
    this(fluent, instance, false);
  }
  public MachineConfigBuilder(io.fabric8.openshift.api.model.machineconfig.v1.MachineConfigFluent<?> fluent,io.fabric8.openshift.api.model.machineconfig.v1.MachineConfig instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withApiVersion(instance.getApiVersion()); 
    fluent.withKind(instance.getKind()); 
    fluent.withMetadata(instance.getMetadata()); 
    fluent.withSpec(instance.getSpec()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public MachineConfigBuilder(io.fabric8.openshift.api.model.machineconfig.v1.MachineConfig instance) {
    this(instance,false);
  }
  public MachineConfigBuilder(io.fabric8.openshift.api.model.machineconfig.v1.MachineConfig instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withApiVersion(instance.getApiVersion()); 
    this.withKind(instance.getKind()); 
    this.withMetadata(instance.getMetadata()); 
    this.withSpec(instance.getSpec()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.machineconfig.v1.MachineConfigFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.machineconfig.v1.MachineConfig build() {
    MachineConfig buildable = new MachineConfig(fluent.getApiVersion(),fluent.getKind(),fluent.getMetadata(),fluent.getSpec());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    MachineConfigBuilder that = (MachineConfigBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> openshift-model-machineconfig-6.6.2-sources.jar: io/fabric8/openshift/api/model/machineconfig/v1/MachineConfigBuilder.java <==
package io.fabric8.openshift.api.model.machineconfig.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class MachineConfigBuilder extends MachineConfigFluentImpl<MachineConfigBuilder> implements VisitableBuilder<MachineConfig,MachineConfigBuilder>{
  public MachineConfigBuilder() {
    this(false);
  }
  public MachineConfigBuilder(Boolean validationEnabled) {
    this(new MachineConfig(), validationEnabled);
  }
  public MachineConfigBuilder(MachineConfigFluent<?> fluent) {
    this(fluent, false);
  }
  public MachineConfigBuilder(MachineConfigFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new MachineConfig(), validationEnabled);
  }
  public MachineConfigBuilder(MachineConfigFluent<?> fluent,MachineConfig instance) {
    this(fluent, instance, false);
  }
  public MachineConfigBuilder(MachineConfigFluent<?> fluent,MachineConfig instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withApiVersion(instance.getApiVersion()); 
    fluent.withKind(instance.getKind()); 
    fluent.withMetadata(instance.getMetadata()); 
    fluent.withSpec(instance.getSpec()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public MachineConfigBuilder(MachineConfig instance) {
    this(instance,false);
  }
  public MachineConfigBuilder(MachineConfig instance,Boolean validationEnabled) {
    this.fluent = this; 
    this.withApiVersion(instance.getApiVersion()); 
    this.withKind(instance.getKind()); 
    this.withMetadata(instance.getMetadata()); 
    this.withSpec(instance.getSpec()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  MachineConfigFluent<?> fluent;
  Boolean validationEnabled;
  public MachineConfig build() {
    MachineConfig buildable = new MachineConfig(fluent.getApiVersion(),fluent.getKind(),fluent.getMetadata(),fluent.getSpec());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}
